@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.003001';
+our $VERSION = '2.003002';
 
 1;
 
@@ -20,7 +20,7 @@ GeoIP2 - Perl API for MaxMind's GeoIP2 web services and databases
 
 =head1 VERSION
 
-version 2.003001
+version 2.003002
 
 =head1 DESCRIPTION
 
@@ -142,7 +142,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack E. Choroba Graham Knop Mateu X Hunter
+=for stopwords Andy Jack E. Choroba Florian Ragwitz Graham Knop Mateu X Hunter
 
 =over 4
 
@@ -156,6 +156,10 @@ E. Choroba <choroba@matfyz.cz>
 
 =item *
 
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
 Graham Knop <haarg@haarg.org>
 
 =item *
