@@ -3,7 +3,7 @@ package GeoIP2::Database::Reader;
 use strict;
 use warnings;
 
-our $VERSION = '2.003001';
+our $VERSION = '2.003002';
 
 use Data::Validate::IP 0.24
     qw( is_ipv4 is_ipv6 is_private_ipv4 is_private_ipv6 );
@@ -188,7 +188,7 @@ GeoIP2::Database::Reader - Perl API for GeoIP2 databases
 
 =head1 VERSION
 
-version 2.003001
+version 2.003002
 
 =head1 SYNOPSIS
 
@@ -339,7 +339,8 @@ about the database.
 
 =head1 EXCEPTIONS
 
-In the case of a fatal error, the reader will throw a L<GeoIP2::Error::Generic>
+In the case of a fatal error, the reader will throw a
+L<GeoIP2::Error::Generic> or L<GeoIP2::Error::IPAddressNotFound> exception
 object.
 
 This error class has an C<< $error->message() >> method and overload
