@@ -3,7 +3,7 @@ package GeoIP2::Record::Location;
 use strict;
 use warnings;
 
-our $VERSION = '2.003001';
+our $VERSION = '2.003002';
 
 use GeoIP2::Types qw( NonNegativeInt Num PositiveInt Str );
 
@@ -65,7 +65,7 @@ GeoIP2::Record::Location - Contains data for the location record associated with
 
 =head1 VERSION
 
-version 2.003001
+version 2.003002
 
 =head1 SYNOPSIS
 
@@ -95,11 +95,13 @@ This class provides the following methods:
 
 =head2 $location_rec->accuracy_radius()
 
-This returns the radius in kilometers around the specified location where the
-IP address is likely to be.
+The approximate accuracy radius in kilometers around the latitude and
+longitude for the IP address. This is the radius where we have a 67%
+confidence that the device using the IP address resides within the circle
+centered at the latitude and longitude with the provided radius.
 
-This attribute is only available from the Insights end point and the GeoIP2
-Enterprise database.
+This attribute is returned by all end points and location databases except
+Country.
 
 =head2 $location_rec->average_income()
 
